==> distribution-6.25.3.zip: drr/standards/iosco/cde/version3/collateral/functions/InitialMarginPostedByReportingCounterpartyPostHaircut.java <==
package drr.standards.iosco.cde.version3.collateral.functions;

import cdm.base.staticdata.party.Party;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.functions.RosettaFunction;
import drr.regulation.common.ReportableCollateral;
import java.math.BigDecimal;
import javax.inject.Inject;


@ImplementedBy(InitialMarginPostedByReportingCounterpartyPostHaircut.InitialMarginPostedByReportingCounterpartyPostHaircutDefault.class)
public abstract class InitialMarginPostedByReportingCounterpartyPostHaircut implements RosettaFunction {
	
	// RosettaFunction dependencies
	//
	@Inject protected drr.standards.iosco.cde.version2.collateral.functions.InitialMarginPostedByReportingCounterpartyPostHaircut initialMarginPostedByReportingCounterpartyPostHaircut;

	/**
	* @param reportableCollateral 
	* @param reportingCounterparty 
	* @return marginValue 
	*/
	public BigDecimal evaluate(ReportableCollateral reportableCollateral, Party reportingCounterparty) {
		BigDecimal marginValue = doEvaluate(reportableCollateral, reportingCounterparty);
		
		return marginValue;
	}

	protected abstract BigDecimal doEvaluate(ReportableCollateral reportableCollateral, Party reportingCounterparty);

	public static class InitialMarginPostedByReportingCounterpartyPostHaircutDefault extends InitialMarginPostedByReportingCounterpartyPostHaircut {
		@Override
		protected BigDecimal doEvaluate(ReportableCollateral reportableCollateral, Party reportingCounterparty) {
			BigDecimal marginValue = null;
			return assignOutput(marginValue, reportableCollateral, reportingCounterparty);
		}
		
		protected BigDecimal assignOutput(BigDecimal marginValue, ReportableCollateral reportableCollateral, Party reportingCounterparty) {
			marginValue = initialMarginPostedByReportingCounterpartyPostHaircut.evaluate(reportableCollateral, reportingCounterparty);
			
			return marginValue;
		}
	}
}

==> distribution-7.0.0-dev.85.zip: drr/standards/iosco/cde/version3/collateral/functions/InitialMarginPostedByReportingCounterpartyPostHaircut.java <==
package drr.standards.iosco.cde.version3.collateral.functions;

import cdm.base.staticdata.party.Party;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.functions.RosettaFunction;
import drr.base.margin.ReportableCollateralBase;
import java.math.BigDecimal;
import javax.inject.Inject;


@ImplementedBy(InitialMarginPostedByReportingCounterpartyPostHaircut.InitialMarginPostedByReportingCounterpartyPostHaircutDefault.class)
public abstract class InitialMarginPostedByReportingCounterpartyPostHaircut implements RosettaFunction {
	
	// RosettaFunction dependencies
	//
	@Inject protected drr.standards.iosco.cde.version2.collateral.functions.InitialMarginPostedByReportingCounterpartyPostHaircut initialMarginPostedByReportingCounterpartyPostHaircut;

	/**
	* @param reportableCollateral 
	* @param reportingCounterparty 
	* @return marginValue 
	*/
	public BigDecimal evaluate(ReportableCollateralBase reportableCollateral, Party reportingCounterparty) {
		BigDecimal marginValue = doEvaluate(reportableCollateral, reportingCounterparty);
		
		return marginValue;
	}

	protected abstract BigDecimal doEvaluate(ReportableCollateralBase reportableCollateral, Party reportingCounterparty);

	public static class InitialMarginPostedByReportingCounterpartyPostHaircutDefault extends InitialMarginPostedByReportingCounterpartyPostHaircut {
		@Override
		protected BigDecimal doEvaluate(ReportableCollateralBase reportableCollateral, Party reportingCounterparty) {
			BigDecimal marginValue = null;
			return assignOutput(marginValue, reportableCollateral, reportingCounterparty);
		}
		
		protected BigDecimal assignOutput(BigDecimal marginValue, ReportableCollateralBase reportableCollateral, Party reportingCounterparty) {
			marginValue = initialMarginPostedByReportingCounterpartyPostHaircut.evaluate(reportableCollateral, reportingCounterparty);
			
			return marginValue;
		}
	}
}
